==> libremail-2.4.1.tar.bz2: libremail/src/utf8-iso8859.c <==
/*
    Fichier utf8-iso8859.c
    Auteur Bernard Chardonneau

    Logiciel libre, droits d'utilisation prciss en franais
    dans le fichier : licence-fr.txt

    Traductions des droits d'utilisation dans les fichiers :
    licence-de.txt , licence-en.txt , licence-es.txt ,
    licence-it.txt , licence-nl.txt , licence-pt.txt ,
    licence-eo.txt , licence-eo-utf.txt

    Droits d'utilisation galement sur la page web :
    http://libremail.tuxfamily.org/voir.php?page=droits


    Remplacement des caractres UTF8 par leur quivallent ASCII
    (pour les caractres correspondant  un code entre A0h et FFh)
*/

#include <stdio.h>


/* programme principal */

int main (int narg, char *varg[])
{
    int car;  // caractre du fichier  convertir


    // utiliser fichiers passs en paramtre  la place du clavier et de l'cran
    if (narg > 1)
        freopen (varg [1], "r", stdin);

    if (narg > 2)
        freopen (varg [2], "w", stdout);

    // lire un caractre
    car = getchar ();

    // tantque non fin de fichier
    while (car != EOF)
    {
        // si caractre 
        if (car == 0xC3)
        {
            // lire le caractre suivant
            car = getchar ();

            // s'il est compris entre 80h et BFh
            if (car >= 0x80 && car < 0xC0)
                // le convertir dans l'encodage iso8859-1
                putchar (car | 0x40);
            // sinon
            else
            {
                // envoyer les 2 derniers caractres lus tels quels
                putchar (0xC3);
                putchar (car);
            }
        }

        // si caractre 
        else if (car == 0xC2)
        {
            // lire le caractre suivant
            car = getchar ();

            // s'il n'est pas compris entre 80h et BFh
            if (car < 0x80 || car >= 0xC0)
                // on renvoie la squence de 2 caractres
                putchar (0xC2);

            // sinon on ne renvoie que le 2me caractre de la squence
            putchar (car);
        }

        // le caractre  suivi du caractre 93h sera remplac par 
        else if (car == 0xC5)
        {
            car = getchar ();

            if (car == 0x93)
                putchar ('');
            else
            {
                putchar (0xC5);
                putchar (car);
            }
        }

        // si caractre  , suivi de 80h, suivi d'un caractre >= 80h
        // on convertira ce 3me caractre
        else if (car == 0xE2)
        {
            car = getchar ();

            if (car == 0x80)
            {
                car = getchar ();

                if (car <= 0x8F)
                    ;  // caractre ignor

                else if (0x9C <= car && car <= 0x9E)
                    putchar ('"');

                else if (car == 0x99)
                    putchar ('\'');

                else if (car == 0xA6)
                {
                    putchar ('.');
                    putchar ('.');
                    putchar ('.');
                }
                else
                {
                    putchar (0xE2);
                    putchar (0x80);
                    putchar (car);
                }
            }
            else
            {
                putchar (0xE2);
                putchar (car);
            }
        }

        // sinon, cas gnral
        else
            // on renvoie le caractre courant
            putchar (car);

        // lire le caractre suivant
        car = getchar ();
    }

    // pour faire plaisir  gcc qui veut une fonction main de type int
    return (0);
}

==> libremail-2.7.tar.bz2: libremail/src/utf8-iso8859.c <==
/*
    Fichier utf8-iso8859.c
    Auteur Bernard Chardonneau

    Logiciel libre, droits d'utilisation prciss en franais
    dans le fichier : licence-fr.txt

    Traductions des droits d'utilisation dans les fichiers :
    licence-de.txt , licence-en.txt , licence-es.txt ,
    licence-it.txt , licence-nl.txt , licence-pt.txt ,
    licence-eo.txt , licence-eo-utf.txt

    Droits d'utilisation galement sur la page web :
    http://libremail.tuxfamily.org/voir.php?page=droits


    Remplacement des caractres UTF8 par leur quivalent ASCII
    (pour les caractres correspondant  un code entre A0h et FFh)
*/

#include <stdio.h>


/* programme principal */

int main (int narg, char *varg[])
{
    int  car;  // caractre du fichier  convertir

    // tableau de conversion des caractres de la srie E2809x
    char E2809x [16] = {'-',  '-',  '-',  '-',  '-',  '-',  '|',  '_',
                        '\'', '\'',  ',',  '`',  '"',  '"',  '"',  '"'};


    // utiliser fichiers passs en paramtre  la place du clavier et de l'cran
    if (narg > 1)
        freopen (varg [1], "r", stdin);

    if (narg > 2)
        freopen (varg [2], "w", stdout);

    // lire un caractre
    car = getchar ();

    // tantque non fin de fichier
    while (car != EOF)
    {
        // si caractre 
        if (car == 0xC3)
        {
            // lire le caractre suivant
            car = getchar ();

            // s'il est compris entre 80h et BFh
            if (car >= 0x80 && car < 0xC0)
                // le convertir dans l'encodage iso8859-1
                putchar (car | 0x40);
            // sinon
            else
            {
                // envoyer les 2 derniers caractres lus tels quels
                putchar (0xC3);
                putchar (car);
            }
        }

        // si caractre 
        else if (car == 0xC2)
        {
            // lire le caractre suivant
            car = getchar ();

            // s'il n'est pas compris entre 80h et BFh
            if (car < 0x80 || car >= 0xC0)
                // on renvoie la squence de 2 caractres
                putchar (0xC2);

            // sinon on ne renvoie que le 2me caractre de la squence
            putchar (car);
        }

        // le caractre  suivi du caractre 93h sera remplac par 
        else if (car == 0xC5)
        {
            car = getchar ();

            if (car == 0x93)
                putchar ('');
            else
            {
                putchar (0xC5);
                putchar (car);
            }
        }

        // si caractre  , suivi de 80h, suivi d'un caractre >= 80h
        // on convertira ce 3me caractre
        else if (car == 0xE2)
        {
            car = getchar ();

            if (car == 0x80)
            {
                car = getchar ();

                if (car <= 0x8F)
                    ;  // caractre ignor

                else if (0x90 <= car && car <= 0x9F)
                    putchar (E2809x [car & 0x0F]);

                else if (car == 0xA6)
                {
                    putchar ('.');
                    putchar ('.');
                    putchar ('.');
                }
                else
                {
                    putchar (0xE2);
                    putchar (0x80);
                    putchar (car);
                }
            }
            else
            {
                putchar (0xE2);
                putchar (car);
            }
        }

        // sinon, cas gnral
        else
            // on renvoie le caractre courant
            putchar (car);

        // lire le caractre suivant
        car = getchar ();
    }

    // pour faire plaisir  gcc qui veut une fonction main de type int
    return (0);
}
